ContentExtent class final

A PanelExtent driven by the measured size of the expanded content.

Inheritance
Annotations

Constructors

ContentExtent({double? maxWidth, double? maxHeightFraction})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
maxHeightFraction → double?
Upper bound on the resolved height as a fraction of the bounds height.
final
maxWidth → double?
Upper bound on the resolved width, before the bounds cap.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(Rect bounds, Size intrinsicContent) → Size
The expanded size inside bounds.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override