FreePlacement class final

A PanelPlacement at an arbitrary normalized position.

Inheritance
Annotations

Constructors

FreePlacement(AlignmentGeometry alignment)
const

Properties

alignment → AlignmentGeometry
Normalized position within PanelViewport.bounds, in the same -1..1 coordinate space as Alignment.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(PanelViewport viewport, Size panelSize, {double stashedPeek = 0}) → Offset
The top-left a panel of panelSize takes in viewport.
override
toJson() → Map<String, Object?>
A JSON-encodable snapshot suitable for persistence.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override