ILoggerFilter class abstract

Determines whether a log message should be recorded based on its content and log level.

Constructors

ILoggerFilter()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldLog(Object? msg, LogLevel level) → bool
Returns true if the log should be recorded.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited