ISpectActionItem class

Annotations

Constructors

ISpectActionItem({required void onTap(BuildContext context)?, required String title, required IconData icon, String? description})
const

Properties

description String?
final
hashCode int
The hash code for this object.
no setteroverride
icon IconData
final
onTap → void Function(BuildContext context)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override