ISpectLocalization class final

Localization class which is used to localize app. This class provides handy methods and tools.

Properties

hashCode int
The hash code for this object.
no setterinherited
locale Locale
Locale which is currently used.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

current ISpectLocalization?
no setter
localizationDelegates List<LocalizationsDelegate<void>>
List of localization delegates.
no setter
supportedLocales List<Locale>
List of supported locales.
no setter

Static Methods

computeDefaultLocale() Locale
Computes the default locale.
of(BuildContext context) ISpectGeneratedLocalization
Obtain ISpectAppLocalizations instance from BuildContext.