notifyObserver method

void notifyObserver(
  1. ISpectObserver observer
)

Notifies the observer about this log entry.

This method uses polymorphic dispatch to call the appropriate observer method. Subclasses can override this to customize which observer method is called.

  • observer: The observer to notify.

Implementation

void notifyObserver(ISpectObserver observer) {
  if (isError) {
    observer.onError(this);
  } else {
    observer.onLog(this);
  }
}