route method

void route(
  1. String message, {
  2. String? transitionId,
})

Creates a route log entry.

These logs are used for tracking navigation events in the application.

  • message: The log message, typically a route name or path.

Implementation

void route(
  String message, {
  String? transitionId,
}) {
  _processLog(RouteLog(message, transitionId: transitionId));
}