ISpectPanelItem class
An item displayed in the ISpect floating panel.
Each item has an icon, an optional badge indicator, and a tap callback that receives the current BuildContext.
- Annotations
Constructors
- ISpectPanelItem({required void onTap(BuildContext context), required bool enableBadge, required IconData icon})
-
Creates a panel item with the given
icon,enableBadgeflag, andonTapcallback.const
Properties
- enableBadge → bool
-
Whether to show a notification badge on this item.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- icon → IconData
-
The icon displayed for this panel item.
final
- onTap → void Function(BuildContext context)
-
Called when the user taps this panel item.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override