ISpectScopeModel class
A model class that holds the state of the ISpect scope.
This class extends ChangeNotifier to allow UI updates when the state changes.
- Inheritance
-
- Object
- ChangeNotifier
- ISpectScopeModel
Constructors
- ISpectScopeModel({bool isISpectEnabled = false, bool isPerformanceTrackingEnabled = false, ISpectOptions? options, ISpectTheme theme = const ISpectTheme(), NavigatorObserver? observer})
-
Creates an instance of
ISpectScopeModel.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isISpectEnabled ↔ bool
-
Indicates whether ISpect is enabled.
getter/setter pair
- isPerformanceTrackingEnabled ↔ bool
-
Indicates whether performance tracking is enabled.
getter/setter pair
- observer ↔ NavigatorObserver?
-
A navigator observer for tracking navigation events.
getter/setter pair
- options ↔ ISpectOptions
-
Configuration options for ISpect.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme ↔ ISpectTheme
-
Theming settings for ISpect.
getter/setter pair
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toggleISpect(
) → void - Toggles the ISpect state.
-
togglePerformanceTracking(
) → void - Toggles the performance tracking state.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited