LogsImportResult class final

Immutable outcome of a bounded log import.

Annotations

Properties

hashCode int
The hash code for this object.
no setterinherited
hasSkippedEntries bool
Whether the caller should disclose a partial import.
no setter
importedEntries int
Number of successfully decoded entries.
no setter
logs List<ISpectLogData>
Successfully decoded log entries.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skippedEntries int
Number of entries rejected because they could not be decoded safely.
final
totalEntries int
Number of entries found in the imported JSON document.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited