MultipartReplayField class final
A single text field of a MultipartReplayBody. Field names may repeat, so parts are modeled as a list rather than a map.
Constructors
- MultipartReplayField(String name, String value)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited