MultipartReplayFile class final
A single file part of a MultipartReplayBody.
Constructors
- MultipartReplayFile({required String field, required ComposerPickedFile file})
-
const
Properties
- field → String
-
Form field name the file is attached to.
final
- file → ComposerPickedFile
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited