SessionStatistics class

Snapshot of session metrics and configuration.

Constructors

SessionStatistics({required int totalDays, required int totalSize, required int totalEntries, required DateTime? oldestDate, required DateTime? newestDate, required int maxSessionDays, required Duration autoSaveInterval, required bool enableAutoSave, required int maxFileSize, required SessionCleanupStrategy cleanupStrategy, int maxTotalSize = 0})
const

Properties

autoSaveInterval Duration
final
cleanupStrategy SessionCleanupStrategy
final
enableAutoSave bool
final
hashCode int
The hash code for this object.
no setterinherited
maxFileSize int
final
maxSessionDays int
final
maxTotalSize int
final
newestDate DateTime?
final
oldestDate DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalDays int
final
totalEntries int
final
totalSize int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited