SourceFilter class

Matches logs whose TraceKeys.source is in sources.

Implemented types

Constructors

SourceFilter(Set<String> sources)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sources Set<String>
final

Methods

apply(ISpectLogData item) bool
Returns true if the item matches the filter condition.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited