DraggablePanelTheme class
Defines the visual properties of a DraggablePanel.
Customize colors, sizes, and spacing at the panel level. For fine-grained control over individual elements, use sub-themes: itemTheme, buttonTheme, tooltipTheme, handleTheme.
- Annotations
Constructors
-
DraggablePanelTheme({double draggableButtonWidth = 35.0, double draggableButtonHeight = 70.0, Color? draggableButtonColor, double panelWidth = 200.0, Color? panelBackgroundColor, BoxBorder? panelBorder, BorderRadiusGeometry panelBorderRadius = const BorderRadius.all(Radius.circular(16)), List<
BoxShadow> ? panelBoxShadow, EdgeInsets panelContentPadding = const EdgeInsets.all(8), Color? panelItemColor, Color? panelButtonColor, Color? foregroundColor, double itemSpacing = 8.0, double buttonSpacing = 6.0, double sectionSpacing = 8.0, DraggablePanelItemThemeData? itemTheme, DraggablePanelButtonThemeData? buttonTheme, DraggablePanelTooltipThemeData? tooltipTheme, DraggablePanelHandleThemeData? handleTheme}) -
const
Properties
-
Spacing between action buttons.
final
-
Theme for action buttons. Uses defaults when null.
final
- draggableButtonColor → Color?
-
Background color of the draggable button.
final
- draggableButtonHeight → double
-
Height of the draggable button.
final
- draggableButtonWidth → double
-
Width of the draggable button.
final
- effectiveButtonTheme → DraggablePanelButtonThemeData
-
no setter
- effectiveHandleTheme → DraggablePanelHandleThemeData
-
no setter
- effectiveItemTheme → DraggablePanelItemThemeData
-
no setter
- effectiveTooltipTheme → DraggablePanelTooltipThemeData
-
no setter
- foregroundColor → Color?
-
Foreground color for icons and text.
final
- handleTheme → DraggablePanelHandleThemeData?
-
Theme for the drag handle. Uses defaults when null.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- itemSpacing → double
-
Spacing between item cells (horizontal and vertical).
final
- itemTheme → DraggablePanelItemThemeData?
-
Theme for item cells. Uses defaults when null.
final
- panelBackgroundColor → Color?
-
Background color of the panel.
final
- panelBorder → BoxBorder?
-
Border of the panel.
final
- panelBorderRadius → BorderRadiusGeometry
-
Border radius of the panel.
final
-
panelBoxShadow
→ List<
BoxShadow> ? -
Shadow of the panel.
final
- panelButtonColor → Color?
-
Background color of action buttons.
final
- panelContentPadding → EdgeInsets
-
Padding inside the panel around its content.
final
- panelItemColor → Color?
-
Background color of item cells in the grid.
final
- panelWidth → double
-
Width of the expanded panel.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sectionSpacing → double
-
Spacing between the items section and the buttons section.
final
- tooltipTheme → DraggablePanelTooltipThemeData?
-
Theme for tooltip snackbars. Uses defaults when null.
final
Methods
-
copyWith(
{double? draggableButtonWidth, double? draggableButtonHeight, Color? draggableButtonColor, double? panelWidth, Color? panelBackgroundColor, BoxBorder? panelBorder, BorderRadiusGeometry? panelBorderRadius, List< BoxShadow> ? panelBoxShadow, EdgeInsets? panelContentPadding, Color? panelItemColor, Color? panelButtonColor, Color? foregroundColor, double? itemSpacing, double? buttonSpacing, double? sectionSpacing, DraggablePanelItemThemeData? itemTheme, DraggablePanelButtonThemeData? buttonTheme, DraggablePanelTooltipThemeData? tooltipTheme, DraggablePanelHandleThemeData? handleTheme}) → DraggablePanelTheme -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override