Contract for log history storage.
Implementations may persist entries in-memory, on disk, or remotely.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
history
→ List<
ISpectLogData> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
ISpectLogData data) → void -
clear(
) → void -
dispose(
) → void - Releases resources (e.g. auto-save timers in FileLogHistory).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited