stream property
Stream<ISpectLogData>
get
stream
Stream controller for broadcasting log events. Stream of log data that can be subscribed to for real-time monitoring.
This stream broadcasts all log events that pass through the filter. Multiple listeners can subscribe to this stream.
Implementation
Stream<ISpectLogData> get stream => _loggerStreamController.stream;