ISpectShareRequest class final
Describes content to pass into a custom share handler.
- Annotations
Constructors
-
const
-
factory
-
factory
Properties
-
filePaths
→ List<
String> -
Absolute file paths to share as attachments.
final
- hasFiles → bool
-
Whether filePaths contains at least one entry.
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → String?
-
Optional subject line (used by platforms that support it, e.g. email).
final
- text → String?
-
Plain-text payload to share.
final
Methods
-
copyWith(
{Object? subject = _sentinel, Object? text = _sentinel, List< String> ? filePaths}) → ISpectShareRequest -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override