ISpectTraceToken class final

Token returned by traceStart for manual span timing.

Always call traceEnd after traceStart. If traceEnd is not called, the Stopwatch continues running until GC (bytes-level leak). traceStart returns null when logger is disabled - calling traceEnd(null) is a no-op.

Constructors

ISpectTraceToken({required Stopwatch stopwatch, required ISpectTraceCategory category, required String source, required String operation, String? target, String? key, Map<String, Object?>? meta, ISpectTraceConfig? config, String? correlationId})

Properties

category ISpectTraceCategory
final
config ISpectTraceConfig?
final
correlationId String?
final
elapsed Duration
no setter
hashCode int
The hash code for this object.
no setterinherited
key String?
final
meta Map<String, Object?>?
final
operation String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
target String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stopTiming() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited