NetworkLoggerMixin mixin
Mixin providing core logging utilities for network interceptors.
Implementing classes must provide logger.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → ISpectLogger
-
The logger instance for network logging.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldProcess<
T> ({required bool enabled, required bool filter(T)?, required T value}) → bool -
Returns
truewhen the interceptor isenabledand the optionalfiltereither isnullor returnstrueforvalue. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
asStringMap(
Object? value) → Map< String, dynamic> ? -
Normalises a raw map value to
Map<String, dynamic>, or returnsnull.