SessionStatistics class
Comprehensive statistics about the current log session.
- totalDays: Number of days with log files
- totalSize: Total size of all log files in bytes
- totalEntries: Total number of log entries across all files
- oldestDate: Date of the oldest log file
- newestDate: Date of the newest log file
- maxSessionDays: Configured maximum session days
- autoSaveInterval: Current auto-save interval
- enableAutoSave: Whether auto-save is currently enabled
- maxFileSize: Maximum file size limit
- cleanupStrategy: Current cleanup strategy
Constructors
- SessionStatistics({required int totalDays, required int totalSize, required int totalEntries, required DateTime? oldestDate, required DateTime? newestDate, required int maxSessionDays, required Duration autoSaveInterval, required bool enableAutoSave, required int maxFileSize, required SessionCleanupStrategy cleanupStrategy})
-
Creates session statistics with comprehensive metrics.
const
Properties
- autoSaveInterval → Duration
-
Current auto-save interval
final
- cleanupStrategy → SessionCleanupStrategy
-
Current cleanup strategy
final
- enableAutoSave → bool
-
Whether auto-save is currently enabled
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxFileSize → int
-
Maximum file size limit in bytes
final
- maxSessionDays → int
-
Configured maximum session days
final
- newestDate → DateTime?
-
Date of the newest log file (null if no files)
final
- oldestDate → DateTime?
-
Date of the oldest log file (null if no files)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalDays → int
-
Number of days with log files
final
- totalEntries → int
-
Total number of log entries across all files
final
- totalSize → int
-
Total size of all log files in bytes
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Converts statistics to a readable string format.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited